svn commit: r13361 - branches/gsoc2007/b00__1/model-euml/src/org/argouml/model/euml/MetaTypesEUMLImpl.java

[email protected]
Newsgroups gmane.comp.lang.uml.argouml.cvs
Message-ID <[email protected]>
Author: b00__1
Date: 2007-08-15 02:12:35-0700
New Revision: 13361

Modified:
   branches/gsoc2007/b00__1/model-euml/src/org/argouml/model/euml/MetaTypesEUMLImpl.java

Log:
Minor changes

Modified: branches/gsoc2007/b00__1/model-euml/src/org/argouml/model/euml/MetaTypesEUMLImpl.java
Url: http://argouml.tigris.org/source/browse/argouml/branches/gsoc2007/b00__1/model-euml/src/org/argouml/model/euml/MetaTypesEUMLImpl.java?view=diff&rev=13361&p1=branches/gsoc2007/b00__1/model-euml/src/org/argouml/model/euml/MetaTypesEUMLImpl.java&p2=branches/gsoc2007/b00__1/model-euml/src/org/argouml/model/euml/MetaTypesEUMLImpl.java&r1=13360&r2=13361
==============================================================================
--- branches/gsoc2007/b00__1/model-euml/src/org/argouml/model/euml/MetaTypesEUMLImpl.java	(original)
+++ branches/gsoc2007/b00__1/model-euml/src/org/argouml/model/euml/MetaTypesEUMLImpl.java	2007-08-15 02:12:35-0700
@@ -44,6 +44,7 @@
 import org.eclipse.uml2.uml.Component;
 import org.eclipse.uml2.uml.DataType;
 import org.eclipse.uml2.uml.Dependency;
+import org.eclipse.uml2.uml.Element;
 import org.eclipse.uml2.uml.Enumeration;
 import org.eclipse.uml2.uml.EnumerationLiteral;
 import org.eclipse.uml2.uml.Extend;
@@ -55,7 +56,6 @@
 import org.eclipse.uml2.uml.Interface;
 import org.eclipse.uml2.uml.Model;
 import org.eclipse.uml2.uml.MultiplicityElement;
-import org.eclipse.uml2.uml.NamedElement;
 import org.eclipse.uml2.uml.Namespace;
 import org.eclipse.uml2.uml.Node;
 import org.eclipse.uml2.uml.ObjectNode;
@@ -133,7 +133,6 @@
     }
 
     public Object getAssociationEnd() {
-        // TODO: Needs checking -tfm
         // an AssociationEnd is now a Property owned by an Association
         return Property.class;
     }
@@ -153,7 +152,6 @@
     }
 
     public Object getAttribute() {
-        // TODO: changed in UML 2.x - needs review - tfm
         return Property.class;
     }
 
@@ -260,7 +258,7 @@
     }
 
     public Object getGeneralizableElement() {
-        // TODO: Gone in UML 2.x - just Classifier now? - tfm
+        // Gone in UML 2.x - just Classifier now
         return Classifier.class;
     }
 
@@ -307,7 +305,7 @@
     }
 
     public Object getModelElement() {
-        return NamedElement.class;
+        return Element.class;
     }
 
     public Object getMultiplicity() {
@@ -333,9 +331,6 @@
         if (name.endsWith(suffix)) {
             endName -= suffix.length();
         }
-        if (endName < 0) {
-            endName = name.length();
-        }
 
         return name.substring(startName, endName);
     }
@@ -355,8 +350,9 @@
     }
 
     public Object getObject() {
-        // TODO: just a guess - double check
-        return org.eclipse.uml2.uml.ObjectNode.class;
+        throw new NotImplementedException();
+        // TODO: what to use: InstanceSpecification, ObjectNode, etc?
+//        return org.eclipse.uml2.uml.ObjectNode.class;
     }
 
     public Object getObjectFlowState() {
@@ -468,8 +464,9 @@
     }
 
     public Object getSubsystem() {
-        // TODO: Changed in UML 2.1 - Package with <<subsystem>> stereotype?
-        return org.eclipse.uml2.uml.Package.class;
+        // Changed in UML 2.1 - Component with <<subsystem>> stereotype
+        // TODO: We should deprecate this?
+        return Component.class;
     }
 
     public Object getSynchState() {
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.